@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Central;
 
-$Map::Tube::London::Line::Central::VERSION = '0.25';
+$Map::Tube::London::Line::Central::VERSION = '0.26';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::London::Line::Central - London Tube Map Central Line stations.
 
 =head1 VERSION
 
-Version 0.25
+Version 0.26
 
 =head1 DESCRIPTION
 
@@ -81,7 +81,8 @@ London Tube Map Central Line stations.
 =item * The station "Notting Hill Gate" is also part of L<District Line|Map::Tube::London::Line::District>.
 
 =item * The station "Liverpool Street" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
-        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>
+        | Metropolitan Line.
 
 =back
 
